import setuptools

setuptools.setup(
    include_package_data=True,
    name='bsl_spelling',
    version='0.0.2',
    description='Test',
    author="Miguel Garcia Hernandez",
    author_email="miguelgarher01@gmail.com",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)